pub struct PulsarPublish;Expand description
The publish policy for PulsarPublisher: pure declaration, constructible anywhere,
paired with the connected broker by the runtime after connect.
Examples
use ruststream_pulsar::PulsarPublish;
let policy = PulsarPublish::default();Trait Implementations
Sourceimpl Clone for PulsarPublish
impl Clone for PulsarPublish
Sourcefn clone(&self) -> PulsarPublish
fn clone(&self) -> PulsarPublish
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PulsarPublish
Sourceimpl Debug for PulsarPublish
impl Debug for PulsarPublish
Sourceimpl Default for PulsarPublish
impl Default for PulsarPublish
Sourcefn default() -> PulsarPublish
fn default() -> PulsarPublish
Returns the “default value” for a type. Read more
Sourceimpl PublishPolicy<ConnectedPulsarBroker> for PulsarPublish
impl PublishPolicy<ConnectedPulsarBroker> for PulsarPublish
Sourcetype Live = PulsarPublisher
type Live = PulsarPublisher
The live form this policy pairs into: a
Publisher for a leaf policy, or the live
wiring form for a combinator stack (a typed publisher over a policy pairs into the same
typed publisher over the live leaf).Auto Trait Implementations
impl Freeze for PulsarPublish
impl RefUnwindSafe for PulsarPublish
impl Send for PulsarPublish
impl Sync for PulsarPublish
impl Unpin for PulsarPublish
impl UnsafeUnpin for PulsarPublish
impl UnwindSafe for PulsarPublish